@@ -1185,7 +1185,7 @@ def queue_validator(section_key, section_label, pcluster_config):
 
     instance_types = []
     for compute_resource_label in compute_resource_labels:
-        compute_resource = pcluster_config.get_section("compute_resource", compute_resource_label)
+        compute_resource = pcluster_config.get_section("compute_resource", compute_resource_label.strip())
         if compute_resource:
             instance_type = compute_resource.get_param_value("instance_type")
             if instance_type in instance_types:
@@ -1208,6 +1208,21 @@ def queue_validator(section_key, section_label, pcluster_config):
     return errors, warnings
 
 
+def queue_compute_type_validator(section_key, section_label, pcluster_config):
+    errors = []
+    warnings = []
+    queue_section = pcluster_config.get_section(section_key, section_label)
+    compute_resource_labels = str(queue_section.get_param_value("compute_resource_settings") or "").split(",")
+
+    for compute_resource_label in compute_resource_labels:
+        # Check that usage class set in queue section is supported by all compute resource instance types
+        compute_resource = pcluster_config.get_section("compute_resource", compute_resource_label.strip())
+        if compute_resource:
+            instance_type = compute_resource.get_param_value("instance_type")
+            check_usage_class(instance_type, queue_section.get_param_value("compute_type"), errors, warnings)
+    return errors, warnings
+
+
 def settings_validator(param_key, param_value, pcluster_config):
     errors = []
     if param_value:
@@ -1266,6 +1281,12 @@ def _get_efa_enabled_instance_types(errors):
             Filters=[{"Name": "network-info.efa-supported", "Values": ["true"]}],
         ):
             instance_types.append(response.get("InstanceType"))
+
+        # Add data from additional instance types
+        for instance_type in InstanceTypeInfo.additional_instance_types_data().keys():
+            instance_type_info = InstanceTypeInfo.init_from_instance_type(instance_type)
+            if instance_type_info.is_efa_supported() and instance_type not in instance_types:
+                instance_types.append(instance_type)
     except ClientError as e:
         errors.append(
             "Failed retrieving efa enabled instance types: {0}".format(e.response.get("Error").get("Message"))
@@ -1561,7 +1582,8 @@ def efa_os_arch_validator(param_key, param_value, pcluster_config):
     architecture = cluster_section.get_param_value("architecture")
     base_os = cluster_section.get_param_value("base_os")
 
-    if base_os in EFA_UNSUPPORTED_ARCHITECTURES_OSES.get(architecture):
+    # The value can be "compute" when specified in the cluster section or True/False when specified in the queue
+    if param_value and base_os in EFA_UNSUPPORTED_ARCHITECTURES_OSES.get(architecture):
         errors.append("EFA currently not supported on {0} for {1} architecture".format(base_os, architecture))
 
     return errors, warnings
@@ -1594,3 +1616,26 @@ def ebs_volume_throughput_validator(section_key, section_label, pcluster_config)
             )
 
     return errors, warnings
+
+
+def cluster_type_validator(param_key, param_value, pcluster_config):
+    errors = []
+    warnings = []
+
+    scheduler = pcluster_config.get_section("cluster").get_param_value("scheduler")
+    if scheduler != "awsbatch":
+        compute_instance_type = pcluster_config.get_section("cluster").get_param_value("compute_instance_type")
+        check_usage_class(compute_instance_type, param_value, errors, warnings)
+
+    return errors, warnings
+
+
+def check_usage_class(instance_type, usage_class, errors, warnings):
+    supported_usage_classes = InstanceTypeInfo.init_from_instance_type(instance_type).supported_usage_classes()
+
+    if not supported_usage_classes:
+        warnings.append(
+            "Could not check support for usage class '{0}' with instance type '{1}'".format(usage_class, instance_type)
+        )
+    elif usage_class not in supported_usage_classes:
+        errors.append("Usage type '{0}' not supported with instance type '{1}'".format(usage_class, instance_type))
